YARP 2.3.64 (2015-06-15)                                              {#v2_3_64}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.61...v2.3.62`):

```
   417	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
   235	Paul Fitzpatrick <paulfitz@alum.mit.edu>
   192	Marco Randazzo <marco.randazzo@iit.it>
   122	Ugo Pattacini <ugo.pattacini@iit.it>
   112	Alberto Cardellino <alberto.cardellino@iit.it>
    55	Davide Perrone <dperrone@aitek.it>
    52	Alessandro Roncone <alessandro.roncone@iit.it>
    50	Lorenzo Natale <lorenzo.natale@iit.it>
    47	Ali Paikan <ali.paikan@iit.it>
    34	Vadim Tikhanoff <vadim.tikhanoff@iit.it>
    14	Konstantinos Theofilis <kostas@ams.eng.osaka-u.ac.jp>
    13	Francesco Romano <francesco.romano@iit.it>
    13	Silvio Traversaro <silvio.traversaro@iit.it>
     8	Alessandro Scalzo <alessandro.scalzo@iit.it>
     7	Elena Ceseracciu <elena.ceseracciu@iit.it>
     7	Matteo Brunettini <matteo.brunettini@iit.it>
     3	Francesco Nori <francesco.nori@iit.it>
     3	YARP Developers <yarp0-devel@lists.sourceforge.net>
     2	Giorgio Metta <giorgio.metta@iit.it>
     2	Holger Friedrich <holgerf@vsi.cs.uni-frankfurt.de>
     1	Carlo Ciliberto <carlo.ciliberto@iit.it>
     1	Giovanni Saponaro <gsaponaro@isr.ist.utl.pt>
     1	Juan G. Victores <jcgvicto@gmail.com>
     1	Matej Hoffmann <matej.hoffmann@iit.it>
     1	Pedro Vicente <pedrovicente07@gmail.com>
```
